# -*- coding: utf-8 -*-
"""
@Author: CaiYouBin
@Date: 2020-05-26 17:51:04
@LastEditTime: 2020-11-10 16:02:18
@LastEditors: HuangJingCan
@Description: 抽奖
"""
from seven_cloudapp.handlers.seven_base import *


class LotteryHandler(SevenBaseHandler):
    """
    @description: 抽奖逻辑实现（业务各自实现）
    """
    def get_async(self):
        """
        @description: 抽奖逻辑实现（业务各自实现）
        @param {*}
        @return {*}
        @last_editors: HuangJingCan
        """
        pass