# -*- coding: utf-8 -*-
"""
@Author: HuangJingCan
@Date: 2020-04-16 14:38:22
@LastEditTime: 2020-08-12 14:44:37
@LastEditors: HuangJingCan
@Description: 
"""
__all__ = ["base_s", "app_s", "user_s", "act_s", "theme_s", "machine_s", "goods_s", "order_s", "prize_s", "report_s", "sms_s", "price_s", "throw_s"]